@@ -2,6 +2,9 @@ import plotly.express as px
 
 from ai_dashboard import Client
 
+def test_import_blocks():
+    from ai_dashboard.tabs.data_report import blocks
+    assert True
 
 def test_create_dashboard(test_client: Client):
     config = {
